﻿using Hotline.BatchTask;
using Quartz;
using Hotline.Share.Enums.BatchTask;
using Hotline.Share.Dtos.Order;
using Microsoft.Extensions.DependencyInjection;

namespace Hotline.Application.Jobs
{
    public class ApptaskJob : IJob, IDisposable
    {
        private readonly IApptaskDomainService _apptaskDomainService;
        private readonly IServiceProvider _serviceProvider;

        public ApptaskJob(IApptaskDomainService apptaskDomainService,
            IServiceProvider serviceProvider)
        {
            _apptaskDomainService = apptaskDomainService;
            _serviceProvider = serviceProvider;
        }

        public async Task Execute(IJobExecutionContext context)
        {
            var task = await _apptaskDomainService.GetWaitingTaskAsync(context.CancellationToken);
            if (task is null) return;
            switch (task.TaskType)
            {
                case ETaskType.Delay:
                    var executor = _serviceProvider.GetService<IApptaskExecutor<BatchDelayNextFlowDto>>();
                    await _apptaskDomainService.ExecuteAsync(executor, task, context.CancellationToken);
                    break;
                case ETaskType.Screen:
                    break;
                default:
                    throw new ArgumentOutOfRangeException();
            }
            
        }

        /// <summary>Performs application-defined tasks associated with freeing, releasing, or resetting unmanaged resources.</summary>
        public void Dispose()
        {
            GC.SuppressFinalize(this);
        }

        
    }
}
